@@ -96,6 +96,7 @@ describe 'tripleo::firewall' do
             '304 add custom application 4' => {'sport' => '1000', 'proto' => 'tcp', 'action' => 'accept'},
             '305 add gre rule'             => {'proto' => 'gre'},
             '306 add custom cidr 2'        => {'port' => 'all', 'destination' => '::1/24'},
+            '307 add custom nat rule'      => {'table' => 'nat', 'source' => '192.168.0.0/24', 'destination' => '192.168.0.0/24', 'jump' => 'RETURN'},
           }
         )
       end
@@ -143,6 +144,12 @@ describe 'tripleo::firewall' do
           :action      => 'accept',
           :provider    => 'ip6tables',
         )
+        is_expected.to contain_firewall('307 add custom nat rule ipv4').with(
+          :destination => '192.168.0.0/24',
+          :source      => '192.168.0.0/24',
+          :jump        => 'RETURN',
+          :table       => 'nat',
+        )
       end
     end
 
